#pragma once

#include <JuceHeader.h>

/* A simple component containing two buttons */
class ComponentWithButtons : public juce::Component
{
public:
    ComponentWithButtons (const juce::Colour& backgroundColour) :
    Component (""),
    bgColour (backgroundColour)
    {
        aButton.setBounds (10, 10, 40, 40);
        addAndMakeVisible (aButton);

        bButton.setBounds (50, 10, 40, 40);
        addAndMakeVisible (bButton);

        setSize (100, 60);
    }

    void paint (juce::Graphics& g) override
    {
        g.fillAll (bgColour);
        if (hasKeyboardFocus (true))
        {
            g.setColour (juce::Colours::white.withAlpha (0.5f));
            g.drawRect (getLocalBounds ().reduced (2), 4);
        }
    }

    void focusOfChildComponentChanged (FocusChangeType) override { repaint (); }

private:
    juce::Colour bgColour;
    juce::TextButton aButton {"A"};
    juce::TextButton bButton {"B"};
};

//==============================================================================
/*
    This component lives inside our window, and this is where you should put all
    your controls and content.
*/
class MainComponent  : public juce::Component
{
public:
    //==============================================================================
    MainComponent();
    ~MainComponent() override;

    //==============================================================================
    void paint (juce::Graphics&) override;
    void resized() override;

private:
    //==============================================================================
    // Your private member variables go here...
    juce::TextButton showLabelOnDesktopButton {"Show/Hide"};

    ComponentWithButtons goodExample {juce::Colours::darkgreen};
    ComponentWithButtons badExample  {juce::Colours::darkred};

    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (MainComponent)
};
